package com.sztzjy.money_management.controller;

import com.github.pagehelper.PageHelper;
import com.github.pagehelper.PageInfo;
import com.sztzjy.money_management.annotation.AnonymousAccess;
import com.sztzjy.money_management.config.Constant;
import com.sztzjy.money_management.entity.*;
import com.sztzjy.money_management.entity.dto.SynthesisPlanScoreDto;
import com.sztzjy.money_management.entity.dto.UserStatisticsDto;
import com.sztzjy.money_management.mapper.*;
import com.sztzjy.money_management.util.ResultEntity;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.web.bind.annotation.*;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;
import java.util.UUID;
import java.util.regex.Pattern;

//综合规划相关
@RestController
@Api(tags = "综合规划相关")
@RequestMapping("api/SynthesisPlanController")
public class SynthesisPlanController {
    @Autowired
    SynthesisPlanClientMapper synthesisPlanClientMapper;
    @Autowired
    WorkScheduleMapper workScheduleMapper;
    @Autowired
    SynthesisPlanScoreMapper synthesisPlanScoreMapper;
    @Autowired
    UserInfoMapper userInfoMapper;
    @Autowired
    CaseInfoMapper caseInfoMapper;
    @Autowired
    UserStatisticsMapper userStatisticsMapper;

    //目标客户查询
    //根据create_time排序
    @AnonymousAccess
    @ApiOperation("目标客户查询")
    @PostMapping("selectTargetCustomer")
    public ResultEntity<PageInfo<SynthesisPlanClient>> selectTargetCustomer(@RequestParam String userId,
                                                                            @RequestParam String schoolId,
                                                                            @RequestParam Integer index,
                                                                            @RequestParam Integer size,
                                                                            @ApiParam("客户姓名/身份证号") @RequestParam(required = false) String param) {
        //先根据userID和source查询所有数据 注意 学生跟踪客户后 会生成一条SynthesisPlanClient数据，需要去重
        PageHelper.startPage(index, size);
        List<String> sourceList=new ArrayList<>();
        sourceList.add(Constant.BUILT_IN_SCHOOL_ID);
        sourceList.add(schoolId);
        SynthesisPlanClientExample neiZhiExample = new SynthesisPlanClientExample();
        SynthesisPlanClientExample.Criteria criteria = neiZhiExample.createCriteria();
        if (StringUtils.isNotBlank(param)){
            if(Pattern.matches("\\d+", param)){
                criteria.andIdcardLike("%"+param+"%");
            }else {
                criteria.andNameLike("%"+param+"%");
            }
        }
        criteria.andUseridIsNull().andSourceIn(sourceList);
        neiZhiExample.setOrderByClause("create_time asc");
        List<SynthesisPlanClient> synthesisPlanClients = synthesisPlanClientMapper.selectByExample(neiZhiExample);

        //获取领取状态
        for (int i = 0; i < synthesisPlanClients.size(); i++) {
            SynthesisPlanClientExample example = new SynthesisPlanClientExample();
            example.createCriteria().andUseridEqualTo(userId).andCaseidEqualTo(synthesisPlanClients.get(i).getCaseid()).andGetStatusEqualTo("true");
            List<SynthesisPlanClient> stuClients = synthesisPlanClientMapper.selectByExample(example);
            if(!stuClients.isEmpty()){
                synthesisPlanClients.get(i).setGetStatus("true");
            }
        }
        PageInfo<SynthesisPlanClient> pageInfo = new PageInfo<>(synthesisPlanClients);
        return new ResultEntity<>(pageInfo);
    }

    //目标客户跟踪
    @AnonymousAccess
    @ApiOperation("目标客户跟踪")
    @PostMapping("TrackDownTargetCustomer")
    public Boolean TrackDownTargetCustomer(@RequestParam String userId, @RequestParam String stuClientId) {
        SynthesisPlanClient synthesisPlanClient = synthesisPlanClientMapper.selectByPrimaryKey(stuClientId);
        synthesisPlanClient.setGetStatus("true");
        synthesisPlanClient.setGetTime(new Date());
        synthesisPlanClient.setUserid(userId);
        int i = synthesisPlanClientMapper.updateByPrimaryKeySelective(synthesisPlanClient);
        return i==1;
    }

    //工作日程新增与编辑
    @AnonymousAccess
    @ApiOperation("工作日程新增与编辑")
    @PostMapping("insertAndUpdateWorkSchedule")
    public Boolean insertWorkSchedule(@RequestParam String userId, @RequestBody WorkSchedule workSchedule) {
        if(StringUtils.isBlank(workSchedule.getWorkScheduleId())){  //代表新增
            workSchedule.setWorkScheduleId(String.valueOf(UUID.randomUUID()));
            workSchedule.setUserId(userId);
            int i = workScheduleMapper.insert(workSchedule);
            return i==1;
        }else { //编辑
            int i = workScheduleMapper.updateByPrimaryKeySelective(workSchedule);
            return i==1;
        }
    }

    //工作日程列表查询
    @AnonymousAccess
    @ApiOperation("工作日程列表查询")
    @PostMapping("selectWorkScheduleList")
    public ResultEntity<PageInfo<WorkSchedule>> selectWorkScheduleList(@RequestParam String userId,
                                                                       @ApiParam("开始时间") @RequestParam Date startTime,
                                                                       @ApiParam("结束时间") @RequestParam Date endTime,@RequestParam Integer index,@RequestParam Integer size) {
        PageHelper.startPage(index, size);
        WorkScheduleExample example = new WorkScheduleExample();
        WorkScheduleExample.Criteria criteria = example.createCriteria();
        criteria.andUserIdEqualTo(userId).andOrderTimeBetween(startTime,endTime);
        List<WorkSchedule> workSchedules = workScheduleMapper.selectByExample(example);
        PageInfo<WorkSchedule> pageInfo = new PageInfo<>(workSchedules);
        return new ResultEntity<>(HttpStatus.OK, "工作日程列表查询成功！",pageInfo);
    }

    //工作日程详情查询
    @AnonymousAccess
    @ApiOperation("工作日程详情查询")
    @GetMapping("selectWorkSchedule")
    public ResultEntity<WorkSchedule> selectWorkSchedule(@RequestParam String workScheduleId) {
        WorkSchedule workSchedule = workScheduleMapper.selectByPrimaryKey(workScheduleId);
        return new ResultEntity<>(HttpStatus.OK, "工作日程详情查询成功！",workSchedule);
    }

    //工作日程删除
    @AnonymousAccess
    @ApiOperation("工作日程删除")
    @GetMapping("deleteWorkSchedule")
    public ResultEntity deleteWorkSchedule(@RequestParam String workScheduleId) {
        int i = workScheduleMapper.deleteByPrimaryKey(workScheduleId);
        if(i==1){
            return new ResultEntity<>(HttpStatus.OK, "工作日程删除成功！");
        }
        return new ResultEntity<>(HttpStatus.BAD_REQUEST, "工作日程删除失败！");
    }


    //规划报告列表展示
    @AnonymousAccess
    @ApiOperation("规划报告列表展示")
    @PostMapping("selectPlanningReportList")
    public ResultEntity<PageInfo<SynthesisPlanClient>> selectPlanningReportList(@RequestParam String userId,
                                                                            @ApiParam("理财类型")@RequestParam String manageMoneyMattersType,
                                                                            @ApiParam("提交状态")@RequestParam String submitStatus,
                                                                            @ApiParam("查询参数")@RequestParam String param,@RequestParam Integer index,@RequestParam Integer size) {
        PageHelper.startPage(index, size);
        SynthesisPlanClientExample example = new SynthesisPlanClientExample();
        SynthesisPlanClientExample.Criteria criteria = example.createCriteria();
        criteria.andUseridEqualTo(userId);
        if(StringUtils.isBlank(submitStatus)){
            List<String> submitStatusList=new ArrayList<>();
            submitStatusList.add("未审核");
            submitStatusList.add("已审核");
            submitStatusList.add("未提交");
            criteria.andSubmitStatusIn(submitStatusList);
        }else {
            criteria.andSubmitStatusEqualTo(submitStatus);
        }
        if(StringUtils.isNotBlank(manageMoneyMattersType)){
            criteria.andManageMoneyMattersTypeEqualTo(manageMoneyMattersType);
        }
        if(StringUtils.isNotBlank(param)){
            SynthesisPlanClientExample.Criteria criteria1 = example.createCriteria();
            SynthesisPlanClientExample.Criteria criteria2 = example.createCriteria();
            SynthesisPlanClientExample.Criteria criteria3 = example.createCriteria();
            SynthesisPlanClientExample.Criteria criteria4 = example.createCriteria();
            criteria1.andProposalNumberLike("%" + param + "%");
            criteria2.andProposalNameLike("%" + param + "%");
            criteria3.andNameLike("%" + param + "%");
            criteria4.andIdcardLike("%" + param + "%");
            example.or(criteria1);
            example.or(criteria2);
            example.or(criteria3);
            example.or(criteria4);
        }
        example.setOrderByClause("create_time asc");
        List<SynthesisPlanClient> synthesisPlanClients = synthesisPlanClientMapper.selectByExample(example);
        PageInfo<SynthesisPlanClient> pageInfo = new PageInfo<>(synthesisPlanClients);
        return new ResultEntity<>(HttpStatus.OK, "规划报告列表展示成功！",pageInfo);
    }

    //规划报告提交
    @AnonymousAccess
    @ApiOperation("规划报告提交")
    @PostMapping("submitPlanningReport")
    public ResultEntity submitPlanningReport(@RequestParam String stuClientId,@RequestParam String userId) {
        SynthesisPlanClient synthesisPlanClient = synthesisPlanClientMapper.selectByPrimaryKey(stuClientId);
        if(synthesisPlanClient.getUserid().equals(userId) && synthesisPlanClient.getSubmitStatus().equals("未提交")){
            synthesisPlanClient.setSubmitStatus("未审核");
            return new ResultEntity<>(HttpStatus.OK, "规划报告提交成功！");
        }
        return new ResultEntity<>(HttpStatus.BAD_REQUEST, "规划报告提交失败！提交状态错误");
    }

    //已有客户、规划报告删除
    @AnonymousAccess
    @ApiOperation("已有客户、规划报告删除")
    @PostMapping("deletePlanningReport")
    public ResultEntity deletePlanningReport(@RequestParam String stuClientId) {
        int i = synthesisPlanClientMapper.deleteByPrimaryKey(stuClientId);
        if(i==1){
            return new ResultEntity<>(HttpStatus.OK, "删除成功！");
        }
        return new ResultEntity<>(HttpStatus.BAD_REQUEST, "删除失败！");
    }

    //规划报告审核报告展示
    @AnonymousAccess
    @ApiOperation("规划报告审核报告展示")
    @PostMapping("selectSynthesisPlanScoreList")
    public ResultEntity<SynthesisPlanScoreDto> selectSynthesisPlanScoreList(@RequestParam String caseId,@RequestParam String userId,@RequestParam Integer index,@RequestParam Integer size) {
        //获取审核类容
        PageHelper.startPage(index, size);
        SynthesisPlanScoreExample example = new SynthesisPlanScoreExample();
        example.createCriteria().andCaseidEqualTo(caseId).andUseridEqualTo(userId);
        List<SynthesisPlanScore> synthesisPlanScores = synthesisPlanScoreMapper.selectByExample(example);
        PageInfo<SynthesisPlanScore> pageInfo = new PageInfo<>(synthesisPlanScores);
        SynthesisPlanScoreDto synthesisPlanScoreDto = new SynthesisPlanScoreDto();
        synthesisPlanScoreDto.setContent(pageInfo);
        //根据userID获取学号和姓名
        UserInfo userInfo = userInfoMapper.selectByPrimaryKey(userId);
        synthesisPlanScoreDto.setStudentId(userInfo.getStudentId());
        //根据caseID获取案例题客户背景
        CaseInfo caseInfo = caseInfoMapper.selectByPrimaryKey(caseId);
        synthesisPlanScoreDto.setCustomerBackdrop(caseInfo.getCustomerBackdrop());
        //获取总成绩
        Double totalScore=synthesisPlanScoreMapper.getTotalScore(userId,caseId);
        synthesisPlanScoreDto.setTotalScore(totalScore);
        return new ResultEntity<>(HttpStatus.OK, "规划报告审核报告展示成功！",synthesisPlanScoreDto);
    }

    //已有客户列表查询
    @AnonymousAccess
    @ApiOperation("已有客户列表查询")
    @PostMapping("selectExistingCustomersList")
    public ResultEntity<PageInfo<SynthesisPlanClient>> selectExistingCustomersList(@RequestParam String userId,
                                                                            @RequestParam Integer index,
                                                                            @RequestParam Integer size,
                                                                            @ApiParam("客户编号/客户姓名/身份证号") @RequestParam(required = false) String param) {
        PageHelper.startPage(index, size);
        SynthesisPlanClientExample example = new SynthesisPlanClientExample();
        SynthesisPlanClientExample.Criteria criteria = example.createCriteria();
        criteria.andUseridEqualTo(userId).andSubmitStatusEqualTo("已审核");
        if(StringUtils.isNotBlank(param)){
            SynthesisPlanClientExample.Criteria criteria1 = example.createCriteria();
            SynthesisPlanClientExample.Criteria criteria2 = example.createCriteria();
            SynthesisPlanClientExample.Criteria criteria3 = example.createCriteria();
            criteria1.andClientNumberLike("%" + param + "%");
            criteria2.andNameLike("%" + param + "%");
            criteria3.andIdcardLike("%" + param + "%");
            example.or(criteria1);
            example.or(criteria2);
            example.or(criteria3);
        }
        example.setOrderByClause("create_time asc");
        List<SynthesisPlanClient> synthesisPlanClients = synthesisPlanClientMapper.selectByExample(example);
        PageInfo<SynthesisPlanClient> pageInfo = new PageInfo<>(synthesisPlanClients);
        return new ResultEntity<>(HttpStatus.OK, "已有客户列表查询成功！",pageInfo);
    }


    //客户统计
    @AnonymousAccess
    @ApiOperation("客户统计查询")
    @PostMapping("selectUserStatistics")
    public ResultEntity<UserStatisticsDto> selectUserStatistics(@RequestParam String userId){
        //先获取已有客户总数
        Integer yiYouTotalCount=synthesisPlanClientMapper.selectYiYouTotalCount(userId);
        //获取潜在客户总数
        Integer qianZaiTotalCount=synthesisPlanClientMapper.selectQianZaiTotalCount(userId);

        //获取高净值数据
        UserStatistics userStatistics = userStatisticsMapper.selectByPrimaryKey(userId);
        UserStatisticsDto userStatisticsDto = new UserStatisticsDto();
        userStatisticsDto.setQianZaiTotalCount(qianZaiTotalCount);
        userStatisticsDto.setYiYouTotalCount(yiYouTotalCount);
        userStatisticsDto.setHighNetClientHaveCount(userStatistics.getHighNetClientHaveCount());
        userStatisticsDto.setHighNetClientLatentCount(userStatistics.getHighNetClientLatentCount());
        return new ResultEntity<>(HttpStatus.OK, "客户统计查询成功！",userStatisticsDto);
    }
}
