package com.sztzjy.money_management.service.impl;

import cn.hutool.core.util.IdUtil;
import com.nimbusds.jose.shaded.gson.Gson;
import com.nimbusds.jose.shaded.gson.JsonSyntaxException;
import com.sztzjy.money_management.entity.*;
import com.sztzjy.money_management.mapper.*;
import com.sztzjy.money_management.service.CaseService;
import com.sztzjy.money_management.util.ResultEntity;
import org.apache.commons.lang3.StringUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.stereotype.Service;

import java.time.LocalDate;
import java.time.format.DateTimeFormatter;
import java.util.Date;
import java.util.List;
import java.util.Random;

/**
 * @Author xcj
 * @Date 2024/8/12
 */
@Service
public class CaseServiceImpl implements CaseService {
    @Autowired
    private CaseInfoMapper caseInfoMapper;
    @Autowired
    private CaseCashPlanMapper caseCashPlanMapper;
    @Autowired
    private CaseLifeEducationPlanMapper caseLifeEducationPlanMapper;
    @Autowired
    private CaseStartAnUndertakingPlanMapper caseStartAnUndertakingPlanMapper;
    @Autowired
    private CaseRetirementPlanMapper caseRetirementPlanMapper;
    @Autowired
    private CaseInsurancePlanMapper caseInsurancePlanMapper;
    @Autowired
    private CaseTaxPlanMapper caseTaxPlanMapper;
    @Autowired
    private CaseDistributionOfPropertyMapper caseDistributionOfPropertyMapper;
    @Autowired
    private CaseHeritageMapper caseHeritageMapper;
    @Autowired
    private ComCaseMapper comCaseMapper;
    @Autowired
    private CaseRiskIndexMapper caseRiskIndexMapper;
    @Autowired
    private CaseFinanceLiabilityMapper caseFinanceLiabilityMapper;
    @Autowired
    private CaseIncomeAndExpensesMapper caseIncomeAndExpensesMapper;
    @Autowired
    private CaseCashFlowMapper caseCashFlowMapper;
    @Autowired
    private CaseFinancialRatiosMapper caseFinancialRatiosMapper;
    @Autowired
    private SynthesisPlanClientMapper synthesisPlanClientMapper;
    @Autowired
    private StuTrainingMapper stuTrainingMapper;

    private void insertSynthesisPlanClient(CaseInfo newCase) {
        SynthesisPlanClient synthesisPlanClient = new SynthesisPlanClient();

        // 获取当前日期
        LocalDate currentDate = LocalDate.now();

        // 定义日期格式
        DateTimeFormatter formatter = DateTimeFormatter.ofPattern("yyyyMMdd");

        // 格式化当前日期为字符串
        String formattedDate = currentDate.format(formatter);

        SynthesisPlanClientExample example1 = new SynthesisPlanClientExample();
        example1.setOrderByClause("createTime");
        List<SynthesisPlanClient> synthesisPlanClients = synthesisPlanClientMapper.selectByExample(example1);

        String clientNumber;
        if (synthesisPlanClients == null || synthesisPlanClients.isEmpty()) {
            // 如果没有记录，创建新的编号
            clientNumber = "C" + formattedDate + "000001";
        } else {
            // 获取最新的记录
            SynthesisPlanClient latestClient = synthesisPlanClients.get(0);
            clientNumber = latestClient.getClientNumber();

            // 提取日期和编号部分
            String datePart = clientNumber.substring(1, 9); // 取出日期部分
            String numberPart = clientNumber.substring(9);  // 取出编号部分

            // 确保日期匹配
            if (datePart.equals(formattedDate)) {
                // 递增编号部分
                int sequenceNumber = Integer.parseInt(numberPart) + 1;
                // 格式化为6位数，不足部分用0填充
                String newNumberPart = String.format("%06d", sequenceNumber);
                // 生成新的客户端编号
                clientNumber = "C" + formattedDate + newNumberPart;
            } else {
                // 日期不匹配，生成随机六位数
                Random random = new Random();
                int number = 1000 + random.nextInt(999999);
                String s = String.valueOf(number);
                // 生成新的客户端编号
                clientNumber = "C" + formattedDate + s;
            }
        }
        // 设置新的客户端编号
        synthesisPlanClient.setStuClientId(IdUtil.randomUUID());
        synthesisPlanClient.setClientNumber(clientNumber);
        synthesisPlanClient.setCaseid(newCase.getCaseid());
        synthesisPlanClient.setName(newCase.getCustomerName());
        synthesisPlanClient.setIdcard(newCase.getIdCard());
        synthesisPlanClient.setManageMoneyMattersType(newCase.getManageMoneyMattersType());
        synthesisPlanClient.setSource(newCase.getSource());
        synthesisPlanClient.setCreateTime(new Date());
        // 插入新的记录
        synthesisPlanClientMapper.insert(synthesisPlanClient);
    }

    @Override
    public ResultEntity<HttpStatus> insertCase(String caseInfo, String json) {
        Gson gson = new Gson();
        CaseInfo newCase = new CaseInfo();
        try {
            if (StringUtils.isNotBlank(caseInfo)) {
                newCase = gson.fromJson(caseInfo, CaseInfo.class);
            }
        } catch (JsonSyntaxException e) {
            e.printStackTrace();
            return new ResultEntity<>(HttpStatus.INTERNAL_SERVER_ERROR, "服务器错误，请联系管理员");
        }
        //判断身份证号是否存在,不存在才新增 客户信息 和综合规划客户表
        CaseInfoExample example = new CaseInfoExample();
        example.createCriteria().andIdCardEqualTo(newCase.getIdCard());
        List<CaseInfo> list = caseInfoMapper.selectByExampleWithBLOBs(example);
        String caseid = "";
        if (list == null || list.isEmpty()) {
            newCase.setCaseid(IdUtil.randomUUID());
            newCase.setAddTime(new Date());
            caseInfoMapper.insert(newCase);

            insertSynthesisPlanClient(newCase);
        } else {
            caseid = list.get(0).getCaseid();
        }

        String type = newCase.getManageMoneyMattersType();

        //综合规划需要额外新增一张表
        if (newCase.getModel().equals("综合规划")) {
            ComCase comCase = new ComCase();
            comCase.setCaseid(caseid);
            comCase.setComCaseId(IdUtil.randomUUID());
            comCase.setManageMoneyMattersType(type);
            comCaseMapper.insert(comCase);
        }

        //判断是哪种考核点 增加相关表
        try {
            if (StringUtils.isNotBlank(json)) {
                if (type.equals("风险测评-风险指标")) {
                    CaseRiskIndex caseRiskIndex = gson.fromJson(json, CaseRiskIndex.class);
                    caseRiskIndex.setCaseRiskIndexId(IdUtil.randomUUID());
                    caseRiskIndex.setCaseid(caseid);
                    caseRiskIndex.setIsAnswer("题目答案");
                    caseRiskIndexMapper.insert(caseRiskIndex);
                    return new ResultEntity<HttpStatus>(HttpStatus.OK, "新增成功！");
                }

                if (type.equals("财务分析-资产负债表")) {
                    CaseFinanceLiability caseFinanceLiability = gson.fromJson(json, CaseFinanceLiability.class);
                    caseFinanceLiability.setCaseFinanceLiabilityId(IdUtil.randomUUID());
                    caseFinanceLiability.setCaseId(caseid);
                    caseFinanceLiability.setIsAnswer("题目答案");
                    caseFinanceLiabilityMapper.insert(caseFinanceLiability);
                    return new ResultEntity<HttpStatus>(HttpStatus.OK, "新增成功！");
                }

                if (type.equals("财务分析-收支储蓄表")) {
                    CaseIncomeAndExpenses caseIncomeAndExpenses = gson.fromJson(json, CaseIncomeAndExpenses.class);
                    caseIncomeAndExpenses.setCaseIncomeAndExpensesId(IdUtil.randomUUID());
                    caseIncomeAndExpenses.setCaseid(caseid);
                    caseIncomeAndExpenses.setIsAnswer("题目答案");
                    caseIncomeAndExpensesMapper.insert(caseIncomeAndExpenses);
                    return new ResultEntity<HttpStatus>(HttpStatus.OK, "新增成功！");
                }

                if (type.equals("财务分析-现金流量表")) {
                    CaseCashFlow caseCashFlow = gson.fromJson(json, CaseCashFlow.class);
                    caseCashFlow.setCaseCashFlowId(IdUtil.randomUUID());
                    caseCashFlow.setCaseid(caseid);
                    caseCashFlow.setIsAnswer("题目答案");
                    caseCashFlowMapper.insert(caseCashFlow);
                    return new ResultEntity<HttpStatus>(HttpStatus.OK, "新增成功！");
                }

                if (type.equals("财务分析-财务比例分析")) {
                    CaseFinancialRatiosWithBLOBs caseFinancialRatios = gson.fromJson(json, CaseFinancialRatiosWithBLOBs.class);
                    caseFinancialRatios.setCaseFinancialRatiosId(IdUtil.randomUUID());
                    caseFinancialRatios.setCaseid(caseid);
                    caseFinancialRatios.setIsAnswer("题目答案");
                    caseFinancialRatiosMapper.insert(caseFinancialRatios);
                    return new ResultEntity<HttpStatus>(HttpStatus.OK, "新增成功！");
                }

                if (type.equals("现金规划")) {
                    CaseCashPlan caseCashPlan = gson.fromJson(json, CaseCashPlan.class);
                    caseCashPlan.setCaseCashPlanId(IdUtil.randomUUID());
                    caseCashPlan.setCaseid(caseid);
                    caseCashPlan.setIsAnswer("题目答案");
                    caseCashPlanMapper.insert(caseCashPlan);
                    return new ResultEntity<HttpStatus>(HttpStatus.OK, "新增成功！");
                }

                if (type.equals("生涯规划-教育规划")) {
                    CaseLifeEducationPlan caseLifeEducationPlan = gson.fromJson(json, CaseLifeEducationPlan.class);
                    caseLifeEducationPlan.setCaseLifeEducationPlanId(IdUtil.randomUUID());
                    caseLifeEducationPlan.setCaseid(caseid);
                    caseLifeEducationPlan.setIsAnswer("题目答案");
                    caseLifeEducationPlanMapper.insert(caseLifeEducationPlan);
                    return new ResultEntity<HttpStatus>(HttpStatus.OK, "新增成功！");
                }

                if (type.equals("生涯规划-消费规划")) {
                    if (StringUtils.isNotBlank(json)) {
                        //todo 暂无数据库表
                        return new ResultEntity<HttpStatus>(HttpStatus.OK, "新增成功！");
                    }
                }


                if (type.equals("生涯规划-创业规划")) {
                    CaseStartAnUndertakingPlan caseStartAnUndertakingPlan = gson.fromJson(json, CaseStartAnUndertakingPlan.class);
                    caseStartAnUndertakingPlan.setCaseStartAnUndertakingPlanId(IdUtil.randomUUID());
                    caseStartAnUndertakingPlan.setCaseid(caseid);
                    caseStartAnUndertakingPlan.setIsAnswer("题目答案");
                    caseStartAnUndertakingPlanMapper.insert(caseStartAnUndertakingPlan);
                    return new ResultEntity<HttpStatus>(HttpStatus.OK, "新增成功！");
                }

                if (type.equals("生涯规划-退休规划")) {
                    CaseRetirementPlan caseRetirementPlan = gson.fromJson(json, CaseRetirementPlan.class);
                    caseRetirementPlan.setCaseRetirementPlanId(IdUtil.randomUUID());
                    caseRetirementPlan.setCaseid(caseid);
                    caseRetirementPlan.setIsAnswer("题目答案");
                    caseRetirementPlanMapper.insert(caseRetirementPlan);
                    return new ResultEntity<HttpStatus>(HttpStatus.OK, "新增成功！");
                }

                if (type.equals("生涯规划-保险规划")) {
                    CaseInsurancePlan caseInsurancePlan = gson.fromJson(json, CaseInsurancePlan.class);
                    caseInsurancePlan.setCaseInsurancePlanId(IdUtil.randomUUID());
                    caseInsurancePlan.setCaseid(caseid);
                    caseInsurancePlan.setIsAnswer("题目答案");
                    caseInsurancePlanMapper.insert(caseInsurancePlan);
                    return new ResultEntity<HttpStatus>(HttpStatus.OK, "新增成功！");
                }

                if (type.equals("投资规划")) {
                    // todo 表暂时没有
                    return null;
                }

                if (type.equals("税务筹划")) {
                    CaseTaxPlan caseTaxPlan = gson.fromJson(json, CaseTaxPlan.class);
                    caseTaxPlan.setCaseTaxPlanId(IdUtil.randomUUID());
                    caseTaxPlan.setCaseid(caseid);
                    caseTaxPlan.setIsAnswer("题目答案");
                    caseTaxPlanMapper.insert(caseTaxPlan);
                    return new ResultEntity<HttpStatus>(HttpStatus.OK, "新增成功！");
                }

                if (type.equals("财产分配")) {
                    CaseDistributionOfPropertyWithBLOBs caseDistributionOfPropertyWithBLOBs = gson.fromJson(json, CaseDistributionOfPropertyWithBLOBs.class);
                    caseDistributionOfPropertyWithBLOBs.setCaseDistributionOfPropertyId(IdUtil.randomUUID());
                    caseDistributionOfPropertyWithBLOBs.setCaseid(caseid);
                    caseDistributionOfPropertyWithBLOBs.setIsAnswer("题目答案");
                    caseDistributionOfPropertyMapper.insert(caseDistributionOfPropertyWithBLOBs);
                    return new ResultEntity<HttpStatus>(HttpStatus.OK, "新增成功！");
                }

                if (type.equals("财产传承")) {
                    CaseHeritageWithBLOBs caseHeritageWithBLOBs = gson.fromJson(json, CaseHeritageWithBLOBs.class);
                    caseHeritageWithBLOBs.setCaseHeritageId(IdUtil.randomUUID());
                    caseHeritageWithBLOBs.setCaseid(caseid);
                    caseHeritageWithBLOBs.setIsAnswer("题目答案");
                    caseHeritageMapper.insert(caseHeritageWithBLOBs);
                    return new ResultEntity<HttpStatus>(HttpStatus.OK, "新增成功！");
                }
            }
        } catch (JsonSyntaxException e) {
            e.printStackTrace();
            return new ResultEntity<>(HttpStatus.INTERNAL_SERVER_ERROR, "服务器错误，请联系管理员");
        }
        return new ResultEntity<>(HttpStatus.BAD_REQUEST, "参数有误！");
    }

    @Override
    public void commitTraining(String json, String type, String trainingId) {
        StuTrainingWithBLOBs stuTrainingWithBLOBs = stuTrainingMapper.selectByPrimaryKey(trainingId);

        int wrongCount = 0;
        Gson gson = new Gson();
        //判断是哪种考核点 增加相关表
        try {
            if (StringUtils.isNotBlank(json)) {
                if (type.equals("风险测评-风险指标")) {
                    CaseRiskIndex stuRiskIndex = gson.fromJson(json, CaseRiskIndex.class);

                    //先查一次数据库，提交过就把原来的记录删掉再重新新增，但是不更新training表的得分
                    CaseRiskIndexExample caseRiskIndexExample = new CaseRiskIndexExample();
                    caseRiskIndexExample.createCriteria().andIsAnswerEqualTo("学生答案").andUseridEqualTo(stuRiskIndex.getUserid()).andCaseidEqualTo(stuRiskIndex.getCaseid());
                    List<CaseRiskIndex> caseRiskIndices = caseRiskIndexMapper.selectByExample(caseRiskIndexExample);
                    if (!caseRiskIndices.isEmpty()) {
                        for (CaseRiskIndex caseRiskIndex : caseRiskIndices) {
                            caseRiskIndexMapper.deleteByPrimaryKey(caseRiskIndex.getCaseRiskIndexId());
                        }
                    }

                    stuRiskIndex.setCaseRiskIndexId(IdUtil.randomUUID());
                    caseRiskIndexMapper.insert(stuRiskIndex);

                    //比较正确答案
                    wrongCount = getRiskIndexWrongCount(wrongCount, stuRiskIndex);
                }

                if (type.equals("财务分析-资产负债表")) {
                    CaseFinanceLiability stuData = gson.fromJson(json, CaseFinanceLiability.class);

                    CaseFinanceLiabilityExample caseRiskIndexExample = new CaseFinanceLiabilityExample();
                    caseRiskIndexExample.createCriteria().andIsAnswerEqualTo("学生答案").andUserIdEqualTo(stuData.getUserId()).andCaseIdEqualTo(stuData.getCaseId());
                    List<CaseFinanceLiability> caseFinanceLiabilities = caseFinanceLiabilityMapper.selectByExample(caseRiskIndexExample);
                    if (!caseFinanceLiabilities.isEmpty()) {
                        for (CaseFinanceLiability caseFinanceLiability : caseFinanceLiabilities) {
                            caseFinanceLiabilityMapper.deleteByPrimaryKey(caseFinanceLiability.getCaseFinanceLiabilityId());
                        }
                    }

                    stuData.setCaseFinanceLiabilityId(IdUtil.randomUUID());
                    caseFinanceLiabilityMapper.insert(stuData);

                    //比较正确答案
                    wrongCount = getCaseFinanceLiabilityWrongCount(wrongCount, stuData);
                }

                if (type.equals("财务分析-收支储蓄表")) {
                    CaseIncomeAndExpenses stuData = gson.fromJson(json, CaseIncomeAndExpenses.class);

                    CaseIncomeAndExpensesExample caseIncomeAndExpensesExample = new CaseIncomeAndExpensesExample();
                    caseIncomeAndExpensesExample.createCriteria().andIsAnswerEqualTo("学生答案").andUserIdEqualTo(stuData.getUserId()).andCaseidEqualTo(stuData.getCaseid());
                    List<CaseIncomeAndExpenses> caseFinanceLiabilities = caseIncomeAndExpensesMapper.selectByExample(caseIncomeAndExpensesExample);
                    if (!caseFinanceLiabilities.isEmpty()) {
                        for (CaseIncomeAndExpenses caseIncomeAndExpenses : caseFinanceLiabilities) {
                            caseIncomeAndExpensesMapper.deleteByPrimaryKey(caseIncomeAndExpenses.getCaseIncomeAndExpensesId());
                        }
                    }

                    stuData.setCaseIncomeAndExpensesId(IdUtil.randomUUID());
                    caseIncomeAndExpensesMapper.insert(stuData);

                    //比较正确答案
                    wrongCount = getCaseIncomeAndExpensesWrongCount(wrongCount, stuData);
                }

                if (type.equals("财务分析-现金流量表")) {
                    CaseCashFlow stuData = gson.fromJson(json, CaseCashFlow.class);

                    CaseCashFlowExample caseCashFlowExample = new CaseCashFlowExample();
                    caseCashFlowExample.createCriteria().andIsAnswerEqualTo("学生答案").andUserIdEqualTo(stuData.getUserId()).andCaseidEqualTo(stuData.getCaseid());
                    List<CaseCashFlow> caseCashFlows = caseCashFlowMapper.selectByExample(caseCashFlowExample);
                    if (!caseCashFlows.isEmpty()) {
                        for (CaseCashFlow caseCashFlow : caseCashFlows) {
                            caseCashFlowMapper.deleteByPrimaryKey(caseCashFlow.getCaseCashFlowId());
                        }
                    }

                    stuData.setCaseCashFlowId(IdUtil.randomUUID());
                    caseCashFlowMapper.insert(stuData);

                    //比较正确答案
                    wrongCount = getCaseCashFlowWrongCount(wrongCount, stuData);
                }

                if (type.equals("财务分析-财务比例分析")) {
                    CaseFinancialRatiosWithBLOBs stuData = gson.fromJson(json, CaseFinancialRatiosWithBLOBs.class);

                    CaseFinancialRatiosExample caseFinancialRatiosExample = new CaseFinancialRatiosExample();
                    caseFinancialRatiosExample.createCriteria().andIsAnswerEqualTo("学生答案").andUserIdEqualTo(stuData.getUserId()).andCaseidEqualTo(stuData.getCaseid());
                    List<CaseFinancialRatiosWithBLOBs> caseFinancialRatiosWithBLOBs = caseFinancialRatiosMapper.selectByExampleWithBLOBs(caseFinancialRatiosExample);
                    if (!caseFinancialRatiosWithBLOBs.isEmpty()) {
                        for (CaseFinancialRatiosWithBLOBs financialRatiosWithBLOBs : caseFinancialRatiosWithBLOBs) {
                            caseFinancialRatiosMapper.deleteByPrimaryKey(financialRatiosWithBLOBs.getCaseFinancialRatiosId());
                        }
                    }

                    stuData.setCaseFinancialRatiosId(IdUtil.randomUUID());
                    caseFinancialRatiosMapper.insert(stuData);

                    //比较正确答案
                    wrongCount = getCaseFinancialRatiosWrongCount(wrongCount, stuData);
                }

                if (type.equals("现金规划")) {
                    CaseCashPlan stuData = gson.fromJson(json, CaseCashPlan.class);

                    CaseCashPlanExample caseCashPlanExample = new CaseCashPlanExample();
                    caseCashPlanExample.createCriteria().andIsAnswerEqualTo("学生答案").andUserIdEqualTo(stuData.getUserId()).andCaseidEqualTo(stuData.getCaseid());
                    List<CaseCashPlan> caseCashFlows = caseCashPlanMapper.selectByExampleWithBLOBs(caseCashPlanExample);
                    if (!caseCashFlows.isEmpty()) {
                        for (CaseCashPlan caseCashPlan : caseCashFlows) {
                            caseCashPlanMapper.deleteByPrimaryKey(caseCashPlan.getCaseCashPlanId());
                        }
                    }

                    stuData.setCaseCashPlanId(IdUtil.randomUUID());
                    caseCashPlanMapper.insert(stuData);

                    //比较正确答案
                    wrongCount = getCaseCashPlanWrongCount(wrongCount, stuData);
                }

                if (type.equals("生涯规划-教育规划")) {
                    CaseLifeEducationPlan stuData = gson.fromJson(json, CaseLifeEducationPlan.class);

                    CaseLifeEducationPlanExample caseLifeEducationPlanExample = new CaseLifeEducationPlanExample();
                    caseLifeEducationPlanExample.createCriteria().andIsAnswerEqualTo("学生答案").andUserIdEqualTo(stuData.getUserId()).andCaseidEqualTo(stuData.getCaseid());
                    List<CaseLifeEducationPlan> caseLifeEducationPlans = caseLifeEducationPlanMapper.selectByExampleWithBLOBs(caseLifeEducationPlanExample);
                    if (!caseLifeEducationPlans.isEmpty()) {
                        for (CaseLifeEducationPlan caseLifeEducationPlan : caseLifeEducationPlans) {
                            caseLifeEducationPlanMapper.deleteByPrimaryKey(caseLifeEducationPlan.getCaseLifeEducationPlanId());
                        }
                    }

                    stuData.setCaseLifeEducationPlanId(IdUtil.randomUUID());
                    caseLifeEducationPlanMapper.insert(stuData);

                    //比较正确答案
                    wrongCount = getCaseLifeEducationPlanWrongCount(wrongCount, stuData);
                }

                if (type.equals("生涯规划-消费规划")) {
                    //todo 暂无数据库表
                }


                if (type.equals("生涯规划-创业规划")) {
                    CaseStartAnUndertakingPlan stuData = gson.fromJson(json, CaseStartAnUndertakingPlan.class);

                    CaseStartAnUndertakingPlanExample caseStartAnUndertakingPlanExample = new CaseStartAnUndertakingPlanExample();
                    caseStartAnUndertakingPlanExample.createCriteria().andIsAnswerEqualTo("学生答案").andUserIdEqualTo(stuData.getUserId()).andCaseidEqualTo(stuData.getCaseid());
                    List<CaseStartAnUndertakingPlan> caseLifeEducationPlans = caseStartAnUndertakingPlanMapper.selectByExampleWithBLOBs(caseStartAnUndertakingPlanExample);
                    if (!caseLifeEducationPlans.isEmpty()) {
                        for (CaseStartAnUndertakingPlan caseStartAnUndertakingPlan : caseLifeEducationPlans) {
                            caseStartAnUndertakingPlanMapper.deleteByPrimaryKey(caseStartAnUndertakingPlan);
                        }
                    }

                    stuData.setCaseStartAnUndertakingPlanId(IdUtil.randomUUID());
                    caseStartAnUndertakingPlanMapper.insert(stuData);

                    //比较正确答案
                    wrongCount = getCaseStartAnUndertakingPlanWrongCount(wrongCount, stuData);
                }

                if (type.equals("生涯规划-退休规划")) {
                    CaseRetirementPlan stuData = gson.fromJson(json, CaseRetirementPlan.class);

                    CaseRetirementPlanExample caseRetirementPlanExample = new CaseRetirementPlanExample();
                    caseRetirementPlanExample.createCriteria().andIsAnswerEqualTo("学生答案").andUserIdEqualTo(stuData.getUserId()).andCaseidEqualTo(stuData.getCaseid());
                    List<CaseRetirementPlan> caseRetirementPlans = caseRetirementPlanMapper.selectByExampleWithBLOBs(caseRetirementPlanExample);
                    if (!caseRetirementPlans.isEmpty()) {
                        for (CaseRetirementPlan caseRetirementPlan : caseRetirementPlans) {
                            caseRetirementPlanMapper.deleteByPrimaryKey(caseRetirementPlan.getCaseRetirementPlanId());
                        }
                    }

                    stuData.setCaseRetirementPlanId(IdUtil.randomUUID());
                    caseRetirementPlanMapper.insert(stuData);

                    //比较正确答案
                    wrongCount = getCaseRetirementPlanWrongCount(wrongCount, stuData);
                }

                if (type.equals("生涯规划-保险规划")) {
                    CaseInsurancePlan stuData = gson.fromJson(json, CaseInsurancePlan.class);

                    CaseInsurancePlanExample caseInsurancePlanExample = new CaseInsurancePlanExample();
                    caseInsurancePlanExample.createCriteria().andIsAnswerEqualTo("学生答案").andUserIdEqualTo(stuData.getUserId()).andCaseidEqualTo(stuData.getCaseid());
                    List<CaseInsurancePlan> caseRetirementPlans = caseInsurancePlanMapper.selectByExampleWithBLOBs(caseInsurancePlanExample);
                    if (!caseRetirementPlans.isEmpty()) {
                        for (CaseInsurancePlan caseInsurancePlan : caseRetirementPlans) {
                            caseInsurancePlanMapper.deleteByPrimaryKey(caseInsurancePlan.getCaseInsurancePlanId());
                        }
                    }

                    stuData.setCaseInsurancePlanId(IdUtil.randomUUID());
                    caseInsurancePlanMapper.insert(stuData);

                    //比较正确答案
                    wrongCount = getCaseInsurancePlanWrongCount(wrongCount, stuData);
                }

                if (type.equals("投资规划")) {
                    // todo 表暂时没有
                }

                if (type.equals("税务筹划")) {
                    CaseTaxPlan stuData = gson.fromJson(json, CaseTaxPlan.class);

                    CaseTaxPlanExample caseTaxPlanExample = new CaseTaxPlanExample();
                    caseTaxPlanExample.createCriteria().andIsAnswerEqualTo("学生答案").andUserIdEqualTo(stuData.getUserId()).andCaseidEqualTo(stuData.getCaseid());
                    List<CaseTaxPlan> caseTaxPlans = caseTaxPlanMapper.selectByExampleWithBLOBs(caseTaxPlanExample);
                    if (!caseTaxPlans.isEmpty()) {
                        for (CaseTaxPlan caseTaxPlan : caseTaxPlans) {
                            caseTaxPlanMapper.deleteByPrimaryKey(caseTaxPlan.getCaseTaxPlanId());
                        }
                    }

                    stuData.setCaseTaxPlanId(IdUtil.randomUUID());
                    caseTaxPlanMapper.insert(stuData);

                    //比较正确答案
                    wrongCount = getCaseTaxPlanWrongCount(wrongCount, stuData);
                }

                if (type.equals("财产分配")) {
                    CaseDistributionOfPropertyWithBLOBs stuData = gson.fromJson(json, CaseDistributionOfPropertyWithBLOBs.class);

                    CaseDistributionOfPropertyExample caseDistributionOfPropertyExample = new CaseDistributionOfPropertyExample();
                    caseDistributionOfPropertyExample.createCriteria().andIsAnswerEqualTo("学生答案").andUserIdEqualTo(stuData.getUserId()).andCaseidEqualTo(stuData.getCaseid());
                    List<CaseDistributionOfPropertyWithBLOBs> caseDistributionOfPropertyWithBLOBs = caseDistributionOfPropertyMapper.selectByExampleWithBLOBs(caseDistributionOfPropertyExample);
                    if (!caseDistributionOfPropertyWithBLOBs.isEmpty()) {
                        for (CaseDistributionOfPropertyWithBLOBs distributionOfPropertyWithBLOBs : caseDistributionOfPropertyWithBLOBs) {
                            caseDistributionOfPropertyMapper.deleteByPrimaryKey(distributionOfPropertyWithBLOBs.getCaseDistributionOfPropertyId());
                        }
                    }

                    stuData.setCaseDistributionOfPropertyId(IdUtil.randomUUID());
                    caseDistributionOfPropertyMapper.insert(stuData);

                    //比较正确答案
                    wrongCount = getCaseDistributionOfPropertyWrongCount(wrongCount, stuData);
                }

                if (type.equals("财产传承")) {
                    CaseHeritageWithBLOBs stuData = gson.fromJson(json, CaseHeritageWithBLOBs.class);
                    stuData.setCaseHeritageId(IdUtil.randomUUID());

                    CaseHeritageExample caseHeritageExample = new CaseHeritageExample();
                    caseHeritageExample.createCriteria().andIsAnswerEqualTo("学生答案").andUserIdEqualTo(stuData.getUserId()).andCaseidEqualTo(stuData.getCaseid());
                    List<CaseHeritageWithBLOBs> caseHeritageWithBLOBs = caseHeritageMapper.selectByExampleWithBLOBs(caseHeritageExample);
                    if (!caseHeritageWithBLOBs.isEmpty()) {
                        for (CaseHeritageWithBLOBs distributionOfPropertyWithBLOBs : caseHeritageWithBLOBs) {
                            caseHeritageMapper.deleteByPrimaryKey(distributionOfPropertyWithBLOBs.getCaseHeritageId());
                        }
                    }
                    caseHeritageMapper.insert(stuData);

                    //比较正确答案
                    wrongCount = getCaseHeritageWrongCount(wrongCount, stuData);
                }
            }
        } catch (Exception e) {
            e.printStackTrace();
            throw new RuntimeException("实训提交失败");
        }

        //第一次添加时设置值 重新实训不提交
        if (stuTrainingWithBLOBs.getExpTrainingCompleteStatus() == null) {
            stuTrainingWithBLOBs.setExpTrainingCompleteStatus(wrongCount);
            stuTrainingMapper.updateByPrimaryKeySelective(stuTrainingWithBLOBs);
        }

    }

    private int getCaseHeritageWrongCount(int wrongCount, CaseHeritageWithBLOBs stuData) {
        CaseHeritageExample example = new CaseHeritageExample();
        example.createCriteria().andCaseidEqualTo(stuData.getCaseid()).andIsAnswerEqualTo("题目答案");
        List<CaseHeritageWithBLOBs> caseHeritageWithBLOBs = caseHeritageMapper.selectByExampleWithBLOBs(example);
        if (caseHeritageWithBLOBs != null && !caseHeritageWithBLOBs.isEmpty()) {
            CaseHeritageWithBLOBs rightData = caseHeritageWithBLOBs.get(0);
            if (stuData.getCash() == null || !stuData.getCash().equals(rightData.getCash())) {
                wrongCount += 1;
            }
            if (stuData.getDeposit() == null || !stuData.getDeposit().equals(rightData.getDeposit())) {
                wrongCount += 1;
            }
            if (stuData.getLifeInsurance() == null || !stuData.getLifeInsurance().equals(rightData.getLifeInsurance())) {
                wrongCount += 1;
            }
            if (stuData.getOtherCashAccount() == null || !stuData.getOtherCashAccount().equals(rightData.getOtherCashAccount())) {
                wrongCount += 1;
            }
            if (stuData.getStock() == null || !stuData.getStock().equals(rightData.getStock())) {
                wrongCount += 1;
            }
            if (stuData.getBond() == null || !stuData.getBond().equals(rightData.getBond())) {
                wrongCount += 1;
            }
            if (stuData.getFund() == null || !stuData.getFund().equals(rightData.getFund())) {
                wrongCount += 1;
            }
            if (stuData.getOtherInvestment() == null || !stuData.getOtherInvestment().equals(rightData.getOtherInvestment())) {
                wrongCount += 1;
            }
            if (stuData.getPension() == null || !stuData.getPension().equals(rightData.getPension())) {
                wrongCount += 1;
            }
            if (stuData.getAnnuityRevenue() == null || !stuData.getAnnuityRevenue().equals(rightData.getAnnuityRevenue())) {
                wrongCount += 1;
            }
            if (stuData.getOtherPension() == null || !stuData.getOtherPension().equals(rightData.getOtherPension())) {
                wrongCount += 1;
            }
            if (stuData.getHouse() == null || !stuData.getHouse().equals(rightData.getHouse())) {
                wrongCount += 1;
            }
            if (stuData.getCar() == null || !stuData.getCar().equals(rightData.getCar())) {
                wrongCount += 1;
            }
            if (stuData.getOther() == null || !stuData.getOther().equals(rightData.getOther())) {
                wrongCount += 1;
            }
            if (stuData.getOtherProperty() == null || !stuData.getOtherProperty().equals(rightData.getOtherProperty())) {
                wrongCount += 1;
            }
            if (stuData.getTotalProperty() == null || !stuData.getTotalProperty().equals(rightData.getTotalProperty())) {
                wrongCount += 1;
            }
            if (stuData.getShortTermLoan() == null || !stuData.getShortTermLoan().equals(rightData.getShortTermLoan())) {
                wrongCount += 1;
            }
            if (stuData.getMediumTermLoans() == null || !stuData.getMediumTermLoans().equals(rightData.getMediumTermLoans())) {
                wrongCount += 1;
            }
            if (stuData.getLongTermLoan() == null || !stuData.getLongTermLoan().equals(rightData.getLongTermLoan())) {
                wrongCount += 1;
            }
            if (stuData.getOtherLoan() == null || !stuData.getOtherLoan().equals(rightData.getOtherLoan())) {
                wrongCount += 1;
            }
            if (stuData.getMedicalCosts() == null || !stuData.getMedicalCosts().equals(rightData.getMedicalCosts())) {
                wrongCount += 1;
            }
            if (stuData.getTaxCosts() == null || !stuData.getTaxCosts().equals(rightData.getTaxCosts())) {
                wrongCount += 1;
            }
            if (stuData.getFuneralExpenses() == null || !stuData.getFuneralExpenses().equals(rightData.getFuneralExpenses())) {
                wrongCount += 1;
            }
            if (stuData.getHeritageCosts() == null || !stuData.getHeritageCosts().equals(rightData.getHeritageCosts())) {
                wrongCount += 1;
            }
            if (stuData.getOtherCosts() == null || !stuData.getOtherCosts().equals(rightData.getOtherCosts())) {
                wrongCount += 1;
            }
            if (stuData.getOtherLiabilities() == null || !stuData.getOtherLiabilities().equals(rightData.getOtherLiabilities())) {
                wrongCount += 1;
            }
            if (stuData.getTotalLiabilities() == null || !stuData.getTotalLiabilities().equals(rightData.getTotalLiabilities())) {
                wrongCount += 1;
            }
            if (stuData.getPlanTool() == null || !stuData.getPlanTool().equals(rightData.getPlanTool())) {
                wrongCount += 1;
            }
            if (stuData.getFinanceAnalysis() == null || !stuData.getFinanceAnalysis().equals(rightData.getFinanceAnalysis())) {
                wrongCount += 1;
            }
            if (stuData.getPlanAnalysis() == null || !stuData.getPlanAnalysis().equals(rightData.getPlanAnalysis())) {
                wrongCount += 1;
            }
        }
        return wrongCount;
    }

    private int getCaseDistributionOfPropertyWrongCount(int wrongCount, CaseDistributionOfPropertyWithBLOBs stuData) {
        CaseDistributionOfPropertyExample example = new CaseDistributionOfPropertyExample();
        example.createCriteria().andCaseidEqualTo(stuData.getCaseid()).andIsAnswerEqualTo("题目答案");
        List<CaseDistributionOfPropertyWithBLOBs> caseDistributionOfPropertyWithBLOBs = caseDistributionOfPropertyMapper.selectByExampleWithBLOBs(example);
        if (caseDistributionOfPropertyWithBLOBs != null && !caseDistributionOfPropertyWithBLOBs.isEmpty()) {
            CaseDistributionOfPropertyWithBLOBs rightData = caseDistributionOfPropertyWithBLOBs.get(0);
            if (stuData.getCustomerSex() == null || !stuData.getCustomerSex().equals(rightData.getCustomerSex())) {
                wrongCount += 1;
            }
            if (stuData.getAddress() == null || !stuData.getAddress().equals(rightData.getAddress())) {
                wrongCount += 1;
            }
            if (stuData.getPosition() == null || !stuData.getPosition().equals(rightData.getPosition())) {
                wrongCount += 1;
            }
            if (stuData.getFamilyNum() == null || !stuData.getFamilyNum().equals(rightData.getFamilyNum())) {
                wrongCount += 1;
            }
            if (stuData.getPlanTool() == null || !stuData.getPlanTool().equals(rightData.getPlanTool())) {
                wrongCount += 1;
            }
            if (stuData.getSituationAnalysis() == null || !stuData.getSituationAnalysis().equals(rightData.getSituationAnalysis())) {
                wrongCount += 1;
            }
            if (stuData.getPlanAnalysis() == null || !stuData.getPlanAnalysis().equals(rightData.getPlanAnalysis())) {
                wrongCount += 1;
            }
        }
        return wrongCount;
    }

    private int getCaseTaxPlanWrongCount(int wrongCount, CaseTaxPlan stuData) {
        CaseTaxPlanExample example = new CaseTaxPlanExample();
        example.createCriteria().andCaseidEqualTo(stuData.getCaseid()).andIsAnswerEqualTo("题目答案");
        List<CaseTaxPlan> caseTaxPlans = caseTaxPlanMapper.selectByExampleWithBLOBs(example);

        if (caseTaxPlans != null && !caseTaxPlans.isEmpty()) {
            CaseTaxPlan rightData = caseTaxPlans.get(0);

            if (stuData.getSalary() == null || stuData.getSalary().compareTo(rightData.getSalary()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getSalaryTax() == null || stuData.getSalaryTax().compareTo(rightData.getSalaryTax()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getOperatingRevenue() == null || stuData.getOperatingRevenue().compareTo(rightData.getOperatingRevenue()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getOperatingRevenueTax() == null || stuData.getOperatingRevenueTax().compareTo(rightData.getOperatingRevenueTax()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getEnterprisesRevenue() == null || stuData.getEnterprisesRevenue().compareTo(rightData.getEnterprisesRevenue()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getEnterprisesRevenueTax() == null || stuData.getEnterprisesRevenueTax().compareTo(rightData.getEnterprisesRevenueTax()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getServiceIncome() == null || stuData.getServiceIncome().compareTo(rightData.getServiceIncome()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getServiceIncomeTax() == null || stuData.getServiceIncomeTax().compareTo(rightData.getServiceIncomeTax()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getRemuneration() == null || stuData.getRemuneration().compareTo(rightData.getRemuneration()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getRemunerationTax() == null || stuData.getRemunerationTax().compareTo(rightData.getRemunerationTax()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getLoyalities() == null || stuData.getLoyalities().compareTo(rightData.getLoyalities()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getLoyalitiesTax() == null || stuData.getLoyalitiesTax().compareTo(rightData.getLoyalitiesTax()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getDemise() == null || stuData.getDemise().compareTo(rightData.getDemise()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getDemiseTax() == null || stuData.getDemiseTax().compareTo(rightData.getDemiseTax()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getIncidentalIncome() == null || stuData.getIncidentalIncome().compareTo(rightData.getIncidentalIncome()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getIncidentalIncomeTax() == null || stuData.getIncidentalIncomeTax().compareTo(rightData.getIncidentalIncomeTax()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getInterest() == null || stuData.getInterest().compareTo(rightData.getInterest()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getInterestTax() == null || stuData.getInterestTax().compareTo(rightData.getInterestTax()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getTotalAmount() == null || stuData.getTotalAmount().compareTo(rightData.getTotalAmount()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getTotalTax() == null || stuData.getTotalTax().compareTo(rightData.getTotalTax()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getAnalysis() == null || !stuData.getAnalysis().equals(rightData.getAnalysis())) {
                wrongCount += 1;
            }
        }
        return wrongCount;
    }

    private int getCaseInsurancePlanWrongCount(int wrongCount, CaseInsurancePlan stuData) {
        CaseInsurancePlanExample example = new CaseInsurancePlanExample();
        example.createCriteria().andCaseidEqualTo(stuData.getCaseid()).andIsAnswerEqualTo("题目答案");
        List<CaseInsurancePlan> caseInsurancePlans = caseInsurancePlanMapper.selectByExampleWithBLOBs(example);
        if (caseInsurancePlans != null && !caseInsurancePlans.isEmpty()) {
            CaseInsurancePlan rightData = caseInsurancePlans.get(0);
            if (stuData.getSpouseName() == null || !stuData.getSpouseName().equals(rightData.getSpouseName())) {
                wrongCount += 1;
            }
            if (stuData.getMethodTypeId() == null || !stuData.getMethodTypeId().equals(rightData.getMethodTypeId())) {
                wrongCount += 1;
            }
            if (stuData.getAgeb() == null || !stuData.getAgeb().equals(rightData.getAgeb())) {
                wrongCount += 1;
            }
            if (stuData.getAgec() == null || !stuData.getAgec().equals(rightData.getAgec())) {
                wrongCount += 1;
            }
            if (stuData.getRetirementAgeb() == null || !stuData.getRetirementAgeb().equals(rightData.getRetirementAgeb())) {
                wrongCount += 1;
            }
            if (stuData.getRetirementAgec() == null || !stuData.getRetirementAgec().equals(rightData.getRetirementAgec())) {
                wrongCount += 1;
            }
            if (stuData.getReturnOnInvestmentb() == null || stuData.getReturnOnInvestmentb().compareTo(rightData.getReturnOnInvestmentb()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getReturnOnInvestmentc() == null || stuData.getReturnOnInvestmentc().compareTo(rightData.getReturnOnInvestmentc()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getInflationRateb() == null || stuData.getInflationRateb().compareTo(rightData.getInflationRateb()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getInflationRatec() == null || stuData.getInflationRatec().compareTo(rightData.getInflationRatec()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getRevenueGrowthb() == null || stuData.getRevenueGrowthb().compareTo(rightData.getRevenueGrowthb()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getRevenueGrowthc() == null || stuData.getRevenueGrowthc().compareTo(rightData.getRevenueGrowthc()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getMatrimonialFeeb() == null || stuData.getMatrimonialFeeb().compareTo(rightData.getMatrimonialFeeb()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getMatrimonialFeec() == null || stuData.getMatrimonialFeec().compareTo(rightData.getMatrimonialFeec()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getAfterAccidentRateb() == null || stuData.getAfterAccidentRateb().compareTo(rightData.getAfterAccidentRateb()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getAfterAccidentRatec() == null || stuData.getAfterAccidentRatec().compareTo(rightData.getAfterAccidentRatec()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getExpenditure() == null || stuData.getExpenditure().compareTo(rightData.getExpenditure()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getIncomeb() == null || stuData.getIncomeb().compareTo(rightData.getIncomeb()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getIncomec() == null || stuData.getIncomec().compareTo(rightData.getIncomec()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getReserveFundb() == null || stuData.getReserveFundb().compareTo(rightData.getReserveFundb()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getReserveFundc() == null || stuData.getReserveFundc().compareTo(rightData.getReserveFundc()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getEduAmountb() == null || stuData.getEduAmountb().compareTo(rightData.getEduAmountb()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getEduAmountc() == null || stuData.getEduAmountc().compareTo(rightData.getEduAmountc()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getPensionFundsb() == null || stuData.getPensionFundsb().compareTo(rightData.getPensionFundsb()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getPensionFundsc() == null || stuData.getPensionFundsc().compareTo(rightData.getPensionFundsc()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getDeathExpenseb() == null || stuData.getDeathExpenseb().compareTo(rightData.getDeathExpenseb()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getDeathExpensec() == null || stuData.getDeathExpensec().compareTo(rightData.getDeathExpensec()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getLoanBalanceb() == null || stuData.getLoanBalanceb().compareTo(rightData.getLoanBalanceb()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getLoanBalancec() == null || stuData.getLoanBalancec().compareTo(rightData.getLoanBalancec()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getEarningAssetsb() == null || stuData.getEarningAssetsb().compareTo(rightData.getEarningAssetsb()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getEarningAssetsc() == null || stuData.getEarningAssetsc().compareTo(rightData.getEarningAssetsc()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getInsuranceAmountb() == null || stuData.getInsuranceAmountb().compareTo(rightData.getInsuranceAmountb()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getInsuranceAmountc() == null || stuData.getInsuranceAmountc().compareTo(rightData.getInsuranceAmountc()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getBudgetAmountb() == null || stuData.getBudgetAmountb().compareTo(rightData.getBudgetAmountb()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getBudgetAmountc() == null || stuData.getBudgetAmountc().compareTo(rightData.getBudgetAmountc()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getSupplementaryQuotab() == null || stuData.getSupplementaryQuotab().compareTo(rightData.getSupplementaryQuotab()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getSupplementaryQuotac() == null || stuData.getSupplementaryQuotac().compareTo(rightData.getSupplementaryQuotac()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getAnalysis() == null || !stuData.getAnalysis().equals(rightData.getAnalysis())) {
                wrongCount += 1;
            }
        }
        return wrongCount;
    }

    private int getCaseRetirementPlanWrongCount(int wrongCount, CaseRetirementPlan stuData) {
        CaseRetirementPlanExample example = new CaseRetirementPlanExample();
        example.createCriteria().andCaseidEqualTo(stuData.getCaseid()).andIsAnswerEqualTo("题目答案");
        List<CaseRetirementPlan> caseRetirementPlans = caseRetirementPlanMapper.selectByExampleWithBLOBs(example);
        if (caseRetirementPlans != null && !caseRetirementPlans.isEmpty()) {
            CaseRetirementPlan rightData = caseRetirementPlans.get(0);

            if (stuData.getAge() == null || !stuData.getAge().equals(rightData.getAge())) {
                wrongCount += 1;
            }
            if (stuData.getBeforeInflationRate() == null || stuData.getBeforeInflationRate().compareTo(rightData.getBeforeInflationRate()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getAfterInflationRate() == null || stuData.getAfterInflationRate().compareTo(rightData.getAfterInflationRate()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getRetirementRate() == null || stuData.getRetirementRate().compareTo(rightData.getRetirementRate()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getSociaSecurityRate() == null || stuData.getSociaSecurityRate().compareTo(rightData.getSociaSecurityRate()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getRentRate() == null || stuData.getRentRate().compareTo(rightData.getRentRate()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getOtherRate() == null || stuData.getOtherRate().compareTo(rightData.getOtherRate()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getRetirementAge() == null || !stuData.getRetirementAge().equals(rightData.getRetirementAge())) {
                wrongCount += 1;
            }
            if (stuData.getRetirementYears() == null || !stuData.getRetirementYears().equals(rightData.getRetirementYears())) {
                wrongCount += 1;
            }
            if (stuData.getLivingStandardNow() == null || !stuData.getLivingStandardNow().equals(rightData.getLivingStandardNow())) {
                wrongCount += 1;
            }
            if (stuData.getSatisfaction() == null || !stuData.getSatisfaction().equals(rightData.getSatisfaction())) {
                wrongCount += 1;
            }
            if (stuData.getSatisfactionLivingStandard() == null || !stuData.getSatisfactionLivingStandard().equals(rightData.getSatisfactionLivingStandard())) {
                wrongCount += 1;
            }
            if (stuData.getConvertProportion() == null || stuData.getConvertProportion().compareTo(rightData.getConvertProportion()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getLineageFee() == null || stuData.getLineageFee().compareTo(rightData.getLineageFee()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getRetirementLivingStandard() == null || !stuData.getRetirementLivingStandard().equals(rightData.getRetirementLivingStandard())) {
                wrongCount += 1;
            }
            if (stuData.getAfterLivingStandard() == null || !stuData.getAfterLivingStandard().equals(rightData.getAfterLivingStandard())) {
                wrongCount += 1;
            }
            if (stuData.getSocialInsurance() == null || stuData.getSocialInsurance().compareTo(rightData.getSocialInsurance()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getCommercialInsurance() == null || stuData.getCommercialInsurance().compareTo(rightData.getCommercialInsurance()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getRentIncome() == null || stuData.getRentIncome().compareTo(rightData.getRentIncome()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getOtherIncome() == null || stuData.getOtherIncome().compareTo(rightData.getOtherIncome()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getTotalIncome() == null || stuData.getTotalIncome().compareTo(rightData.getTotalIncome()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getTotalAmount() == null || stuData.getTotalAmount().compareTo(rightData.getTotalAmount()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getReturnOnInvestmentRate() == null || stuData.getReturnOnInvestmentRate().compareTo(rightData.getReturnOnInvestmentRate()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getDisposableInput() == null || stuData.getDisposableInput().compareTo(rightData.getDisposableInput()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getMonthlyInvestment() == null || stuData.getMonthlyInvestment().compareTo(rightData.getMonthlyInvestment()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getRegularYear() == null || !stuData.getRegularYear().equals(rightData.getRegularYear())) {
                wrongCount += 1;
            }
            if (stuData.getTargetAmount() == null || stuData.getTargetAmount().compareTo(rightData.getTargetAmount()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getAnalysis() == null || !stuData.getAnalysis().equals(rightData.getAnalysis())) {
                wrongCount += 1;
            }
        }
        return wrongCount;
    }

    private int getCaseStartAnUndertakingPlanWrongCount(int wrongCount, CaseStartAnUndertakingPlan stuData) {
        CaseStartAnUndertakingPlanExample example = new CaseStartAnUndertakingPlanExample();
        example.createCriteria().andCaseidEqualTo(stuData.getCaseid()).andIsAnswerEqualTo("题目答案");
        List<CaseStartAnUndertakingPlan> caseStartAnUndertakingPlans = caseStartAnUndertakingPlanMapper.selectByExampleWithBLOBs(example);
        if (caseStartAnUndertakingPlans != null && !caseStartAnUndertakingPlans.isEmpty()) {
            CaseStartAnUndertakingPlan rightData = caseStartAnUndertakingPlans.get(0);

            if (stuData.getAge() == null || !stuData.getAge().equals(rightData.getAge())) {
                wrongCount += 1;
            }
            if (stuData.getStartPlanAge() == null || !stuData.getStartPlanAge().equals(rightData.getStartPlanAge())) {
                wrongCount += 1;
            }
            if (stuData.getDistanceYear() == null || !stuData.getDistanceYear().equals(rightData.getDistanceYear())) {
                wrongCount += 1;
            }
            if (stuData.getCostInput() == null || stuData.getCostInput().compareTo(rightData.getCostInput()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getReturnOnInvestmentRate() == null || stuData.getReturnOnInvestmentRate().compareTo(rightData.getReturnOnInvestmentRate()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getDisposableInput() == null || stuData.getDisposableInput().compareTo(rightData.getDisposableInput()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getMonthlyInvestment() == null || stuData.getMonthlyInvestment().compareTo(rightData.getMonthlyInvestment()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getRegularYear() == null || !stuData.getRegularYear().equals(rightData.getRegularYear())) {
                wrongCount += 1;
            }
            if (stuData.getTargetAmount() == null || stuData.getTargetAmount().compareTo(rightData.getTargetAmount()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getAnalysis() == null || !stuData.getAnalysis().equals(rightData.getAnalysis())) {
                wrongCount += 1;
            }
        }
        return wrongCount;
    }

    private int getCaseLifeEducationPlanWrongCount(int wrongCount, CaseLifeEducationPlan stuData) {
        CaseLifeEducationPlanExample example = new CaseLifeEducationPlanExample();
        example.createCriteria().andCaseidEqualTo(stuData.getCaseid()).andIsAnswerEqualTo("题目答案");
        List<CaseLifeEducationPlan> caseLifeEducationPlans = caseLifeEducationPlanMapper.selectByExampleWithBLOBs(example);
        if (caseLifeEducationPlans != null && !caseLifeEducationPlans.isEmpty()) {
            CaseLifeEducationPlan rightData = caseLifeEducationPlans.get(0);

            if (stuData.getChildAge() == null || !stuData.getChildAge().equals(rightData.getChildAge())) {
                wrongCount += 1;
            }
            if (stuData.getInlandEduFee() == null || stuData.getInlandEduFee().compareTo(rightData.getInlandEduFee()) != 0) {
                wrongCount += 1;
            }

            if (stuData.getForeignEduFee() == null || stuData.getForeignEduFee().compareTo(rightData.getForeignEduFee()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getaEduAge() == null || !stuData.getaEduAge().equals(rightData.getaEduAge())) {
                wrongCount += 1;
            }
            if (stuData.getaEduTime() == null || !stuData.getaEduTime().equals(rightData.getaEduTime())) {
                wrongCount += 1;
            }
            if (stuData.getaTuition() == null || stuData.getaTuition().compareTo(rightData.getaTuition()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getaEduTuition() == null || stuData.getaEduTuition().compareTo(rightData.getaEduTuition()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getaTotalTuition() == null || stuData.getaTotalTuition().compareTo(rightData.getaTotalTuition()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getbEduAge() == null || !stuData.getbEduAge().equals(rightData.getbEduAge())) {
                wrongCount += 1;
            }
            if (stuData.getbEduTime() == null || !stuData.getbEduTime().equals(rightData.getbEduTime())) {
                wrongCount += 1;
            }
            if (stuData.getbTuition() == null || stuData.getbTuition().compareTo(rightData.getbTuition()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getbEduTuition() == null || stuData.getbEduTuition().compareTo(rightData.getbEduTuition()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getbTotalTuition() == null || stuData.getbTotalTuition().compareTo(rightData.getbTotalTuition()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getcEduAge() == null || !stuData.getcEduAge().equals(rightData.getcEduAge())) {
                wrongCount += 1;
            }
            if (stuData.getcEduTime() == null || !stuData.getcEduTime().equals(rightData.getcEduTime())) {
                wrongCount += 1;
            }
            if (stuData.getcTuition() == null || stuData.getcTuition().compareTo(rightData.getcTuition()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getcEduTuition() == null || stuData.getcEduTuition().compareTo(rightData.getcEduTuition()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getcTotalTuition() == null || stuData.getcTotalTuition().compareTo(rightData.getcTotalTuition()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getdEduAge() == null || !stuData.getdEduAge().equals(rightData.getdEduAge())) {
                wrongCount += 1;
            }
            if (stuData.getdEduTime() == null || !stuData.getdEduTime().equals(rightData.getdEduTime())) {
                wrongCount += 1;
            }
            if (stuData.getdTuition() == null || stuData.getdTuition().compareTo(rightData.getdTuition()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getdEduTuition() == null || stuData.getdEduTuition().compareTo(rightData.getdEduTuition()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getdTotalTuition() == null || stuData.getdTotalTuition().compareTo(rightData.getdTotalTuition()) != 0) {
                wrongCount += 1;
            }
            if (stuData.geteEduAge() == null || !stuData.geteEduAge().equals(rightData.geteEduAge())) {
                wrongCount += 1;
            }
            if (stuData.geteEduTime() == null || !stuData.geteEduTime().equals(rightData.geteEduTime())) {
                wrongCount += 1;
            }
            if (stuData.geteTuition() == null || stuData.geteTuition().compareTo(rightData.geteTuition()) != 0) {
                wrongCount += 1;
            }
            if (stuData.geteEduTuition() == null || stuData.geteEduTuition().compareTo(rightData.geteEduTuition()) != 0) {
                wrongCount += 1;
            }
            if (stuData.geteTotalTuition() == null || stuData.geteTotalTuition().compareTo(rightData.geteTotalTuition()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getfEduAge() == null || !stuData.getfEduAge().equals(rightData.getfEduAge())) {
                wrongCount += 1;
            }
            if (stuData.getfEduTime() == null || !stuData.getfEduTime().equals(rightData.getfEduTime())) {
                wrongCount += 1;
            }
            if (stuData.getfTuition() == null || stuData.getfTuition().compareTo(rightData.getfTuition()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getfEduTuition() == null || stuData.getfEduTuition().compareTo(rightData.getfEduTuition()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getfTotalTuition() == null || stuData.getfTotalTuition().compareTo(rightData.getfTotalTuition()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getInsurance() == null || stuData.getInsurance().compareTo(rightData.getInsurance()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getDeposit() == null || stuData.getDeposit().compareTo(rightData.getDeposit()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getOther() == null || stuData.getOther().compareTo(rightData.getOther()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getEduTotalAmount() == null || stuData.getEduTotalAmount().compareTo(rightData.getEduTotalAmount()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getReturnOnInvestment() == null || stuData.getReturnOnInvestment().compareTo(rightData.getReturnOnInvestment()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getDisposableInput() == null || stuData.getDisposableInput().compareTo(rightData.getDisposableInput()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getMonthlyInvestment() == null || stuData.getMonthlyInvestment().compareTo(rightData.getMonthlyInvestment()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getRegularYear() == null || !stuData.getRegularYear().equals(rightData.getRegularYear())) {
                wrongCount += 1;
            }
            if (stuData.getTargetAmount() == null || stuData.getTargetAmount().compareTo(rightData.getTargetAmount()) != 0) {
                wrongCount += 1;
            }
        }
        return wrongCount;
    }

    private int getCaseCashPlanWrongCount(int wrongCount, CaseCashPlan stuData) {
        CaseCashPlanExample example = new CaseCashPlanExample();
        example.createCriteria().andCaseidEqualTo(stuData.getCaseid()).andIsAnswerEqualTo("题目答案");
        List<CaseCashPlan> caseCashPlans = caseCashPlanMapper.selectByExampleWithBLOBs(example);
        if (caseCashPlans != null && !caseCashPlans.isEmpty()) {
            CaseCashPlan rightData = caseCashPlans.get(0);
            if (stuData.getFamilyMonthExpense() == null || rightData.getFamilyMonthExpense().compareTo(stuData.getFamilyMonthExpense()) != 0) {
                wrongCount += 1;
            }
            if (StringUtils.isBlank(stuData.getRetainCashType())
                    || !stuData.getRetainCashType().equals(rightData.getRetainCashType())) {
                wrongCount += 1;
            }
            if (stuData.getDeposit() == null || rightData.getDeposit().compareTo(stuData.getDeposit()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getFund() == null || rightData.getFund().compareTo(stuData.getFund()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getCreditCard() == null || rightData.getCreditCard().compareTo(stuData.getCreditCard()) != 0) {
                wrongCount += 1;
            }
        }
        return wrongCount;
    }

    private int getCaseFinancialRatiosWrongCount(int wrongCount, CaseFinancialRatiosWithBLOBs stuData) {
        CaseFinancialRatiosExample example = new CaseFinancialRatiosExample();
        example.createCriteria().andCaseidEqualTo(stuData.getCaseid()).andIsAnswerEqualTo("题目答案");
        List<CaseFinancialRatiosWithBLOBs> caseFinancialRatiosWithBLOBs = caseFinancialRatiosMapper.selectByExampleWithBLOBs(example);
        if (caseFinancialRatiosWithBLOBs != null && !caseFinancialRatiosWithBLOBs.isEmpty()) {
            CaseFinancialRatiosWithBLOBs rightData = caseFinancialRatiosWithBLOBs.get(0);
            if (StringUtils.isBlank(stuData.getLiabilityAnalysis())
                    || !stuData.getLiabilityAnalysis().equals(rightData.getLiabilityAnalysis())) {
                wrongCount += 1;
            }
            if (StringUtils.isBlank(stuData.getIncomeAndExpensesAnalysis())
                    || !stuData.getIncomeAndExpensesAnalysis().equals(rightData.getIncomeAndExpensesAnalysis())) {
                wrongCount += 1;
            }
            if (StringUtils.isBlank(stuData.getAnalysis())
                    || !stuData.getAnalysis().equals(rightData.getAnalysis())) {
                wrongCount += 1;
            }
        }
        return wrongCount;
    }

    private int getCaseCashFlowWrongCount(int wrongCount, CaseCashFlow stuData) {
        CaseCashFlowExample example = new CaseCashFlowExample();
        example.createCriteria().andCaseidEqualTo(stuData.getCaseid()).andIsAnswerEqualTo("题目答案");
        List<CaseCashFlow> caseCashFlows = caseCashFlowMapper.selectByExample(example);
        if (caseCashFlows != null && !caseCashFlows.isEmpty()) {
            CaseCashFlow rightData = caseCashFlows.get(0);
            if (stuData.getRedemption() == null || stuData.getRedemption().compareTo(rightData.getRedemption()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getInvestment() == null || stuData.getInvestment().compareTo(rightData.getInvestment()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getBorrowCapital() == null || stuData.getBorrowCapital().compareTo(rightData.getBorrowCapital()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getRepaymentCapital() == null || stuData.getRepaymentCapital().compareTo(rightData.getRepaymentCapital()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getWorkIncome() == null || stuData.getWorkIncome().compareTo(rightData.getWorkIncome()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getLiveExpense() == null || stuData.getLiveExpense().compareTo(rightData.getLiveExpense()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getInvestIncome() == null || stuData.getInvestIncome().compareTo(rightData.getInvestIncome()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getInterestExpense() == null || stuData.getInterestExpense().compareTo(rightData.getInterestExpense()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getInsuranceExpense() == null || stuData.getInsuranceExpense().compareTo(rightData.getInsuranceExpense()) != 0) {
                wrongCount += 1;
            }
        }
        return wrongCount;
    }

    private int getCaseIncomeAndExpensesWrongCount(int wrongCount, CaseIncomeAndExpenses stuData) {
        CaseIncomeAndExpensesExample example = new CaseIncomeAndExpensesExample();
        example.createCriteria().andCaseidEqualTo(stuData.getCaseid()).andIsAnswerEqualTo("题目答案");
        List<CaseIncomeAndExpenses> caseIncomeAndExpenses = caseIncomeAndExpensesMapper.selectByExample(example);

        if (caseIncomeAndExpenses != null && !caseIncomeAndExpenses.isEmpty()) {
            CaseIncomeAndExpenses rightData = caseIncomeAndExpenses.get(0);
            if (stuData.getJobIncome() == null || stuData.getJobIncome().compareTo(rightData.getJobIncome()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getEndowmentInsurance() == null || stuData.getEndowmentInsurance().compareTo(rightData.getEndowmentInsurance()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getMedicalInsurance() == null || stuData.getMedicalInsurance().compareTo(rightData.getMedicalInsurance()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getHousingFund() == null || stuData.getHousingFund().compareTo(rightData.getHousingFund()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getOtherJobIncome() == null || stuData.getOtherJobIncome().compareTo(rightData.getOtherJobIncome()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getFamilyExpense() == null || stuData.getFamilyExpense().compareTo(rightData.getFamilyExpense()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getChildExpense() == null || stuData.getChildExpense().compareTo(rightData.getChildExpense()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getOtherExpense() == null || stuData.getOtherExpense().compareTo(rightData.getOtherExpense()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getInterest() == null || stuData.getInterest().compareTo(rightData.getInterest()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getCapitalGains() == null || stuData.getCapitalGains().compareTo(rightData.getCapitalGains()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getOtherIncome() == null || stuData.getOtherIncome().compareTo(rightData.getOtherIncome()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getInterestExpense() == null || stuData.getInterestExpense().compareTo(rightData.getInterestExpense()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getInsuranceExpense() == null || stuData.getInsuranceExpense().compareTo(rightData.getInsuranceExpense()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getOtherFinanceExpense() == null || stuData.getOtherFinanceExpense().compareTo(rightData.getOtherFinanceExpense()) != 0) {
                wrongCount += 1;
            }
        }
        return wrongCount;
    }

    private int getCaseFinanceLiabilityWrongCount(int wrongCount, CaseFinanceLiability stuData) {
        CaseFinanceLiabilityExample example = new CaseFinanceLiabilityExample();
        example.createCriteria().andCaseIdEqualTo(stuData.getCaseId()).andIsAnswerEqualTo("题目答案");
        List<CaseFinanceLiability> caseFinanceLiabilities = caseFinanceLiabilityMapper.selectByExample(example);

        if (caseFinanceLiabilities != null && !caseFinanceLiabilities.isEmpty()) {
            CaseFinanceLiability rightData = caseFinanceLiabilities.get(0);
            if (stuData.getCash() == null || rightData.getCash().compareTo(stuData.getCash()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getRmbDeposit() == null || rightData.getRmbDeposit().compareTo(stuData.getRmbDeposit()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getOtherAsset() == null || rightData.getOtherAsset().compareTo(stuData.getOtherAsset()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getRmbFixedDeposit() == null || rightData.getRmbFixedDeposit().compareTo(stuData.getRmbFixedDeposit()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getForeignCurrencyFixedDeposit() == null
                    || rightData.getForeignCurrencyFixedDeposit().compareTo(stuData.getForeignCurrencyFixedDeposit()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getStockInvestment() == null || rightData.getStockInvestment().compareTo(stuData.getStockInvestment()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getBondInvestment() == null || rightData.getBondInvestment().compareTo(stuData.getBondInvestment()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getFundInvestment() == null || rightData.getFundInvestment().compareTo(stuData.getFundInvestment()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getIndustryInvestment() == null || rightData.getIndustryInvestment().compareTo(stuData.getIndustryInvestment()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getEstateInvestment() == null || rightData.getEstateInvestment().compareTo(stuData.getEstateInvestment()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getPolicyInvestment() == null || rightData.getPolicyInvestment().compareTo(stuData.getPolicyInvestment()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getOtherInvestment() == null || rightData.getOtherInvestment().compareTo(stuData.getOtherInvestment()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getEstate() == null || rightData.getEstate().compareTo(stuData.getEstate()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getCar() == null || rightData.getCar().compareTo(stuData.getCar()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getOthers() == null || rightData.getOthers().compareTo(stuData.getOthers()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getTotalAssets() == null || rightData.getTotalAssets().compareTo(stuData.getTotalAssets()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getCreditCard() == null || rightData.getCreditCard().compareTo(stuData.getCreditCard()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getMicrofinance() == null || rightData.getMicrofinance().compareTo(stuData.getMicrofinance()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getOtherLoan() == null || rightData.getOtherLoan().compareTo(stuData.getOtherLoan()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getFinancialLoan() == null || rightData.getFinancialLoan().compareTo(stuData.getFinancialLoan()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getIndustryInvestmentLoan() == null || rightData.getIndustryInvestmentLoan().compareTo(stuData.getIndustryInvestmentLoan()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getEstateInvestmentLoan() == null || rightData.getEstateInvestmentLoan().compareTo(stuData.getEstateInvestmentLoan()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getOtherInvestmentLoan() == null || rightData.getOtherInvestmentLoan().compareTo(stuData.getOtherInvestmentLoan()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getEstateLoan() == null || rightData.getEstateLoan().compareTo(stuData.getEstateLoan()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getCarLoan() == null || rightData.getCarLoan().compareTo(stuData.getCarLoan()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getOthersLoan() == null || rightData.getOthersLoan().compareTo(stuData.getOthersLoan()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getTotalLoan() == null || rightData.getTotalLoan().compareTo(stuData.getTotalLoan()) != 0) {
                wrongCount += 1;
            }
            if (stuData.getTotalNet() == null || rightData.getTotalNet().compareTo(stuData.getTotalNet()) != 0) {
                wrongCount += 1;
            }
        }
        return wrongCount;
    }

    private int getRiskIndexWrongCount(int wrongCount, CaseRiskIndex stuRiskIndex) {
        //查出正确答案
        CaseRiskIndexExample caseRiskIndexExample = new CaseRiskIndexExample();
        caseRiskIndexExample.createCriteria().andCaseidEqualTo(stuRiskIndex.getCaseid()).andIsAnswerEqualTo("题目答案");
        List<CaseRiskIndex> caseRiskIndices = caseRiskIndexMapper.selectByExample(caseRiskIndexExample);

        if (caseRiskIndices != null && !caseRiskIndices.isEmpty()) {
            CaseRiskIndex rightRiskIndex = caseRiskIndices.get(0);
            if (stuRiskIndex.getAdiScore() == null || rightRiskIndex.getAdiScore().compareTo(stuRiskIndex.getAdiScore()) != 0) {
                wrongCount += 1;
            }
            if (stuRiskIndex.getAgeScore() == null || rightRiskIndex.getAgeScore().compareTo(stuRiskIndex.getAgeScore()) != 0) {
                wrongCount += 1;
            }
            if (stuRiskIndex.getAvoidScore() == null || rightRiskIndex.getAvoidScore().compareTo(stuRiskIndex.getAvoidScore()) != 0) {
                wrongCount += 1;
            }
            if (stuRiskIndex.getCharacterScore() == null || rightRiskIndex.getCharacterScore().compareTo(stuRiskIndex.getCharacterScore()) != 0) {
                wrongCount += 1;
            }
            if (stuRiskIndex.getConsiderationScore() == null || rightRiskIndex.getConsiderationScore().compareTo(stuRiskIndex.getConsiderationScore()) != 0) {
                wrongCount += 1;
            }
            if (stuRiskIndex.getExpScore() == null || rightRiskIndex.getExpScore().compareTo(stuRiskIndex.getExpScore()) != 0) {
                wrongCount += 1;
            }
            if (stuRiskIndex.getJobScore() == null || rightRiskIndex.getJobScore().compareTo(stuRiskIndex.getJobScore()) != 0) {
                wrongCount += 1;
            }
            if (stuRiskIndex.getFamilyScore() == null || rightRiskIndex.getFamilyScore().compareTo(stuRiskIndex.getFamilyScore()) != 0) {
                wrongCount += 1;
            }
            if (stuRiskIndex.getHouseScore() == null || rightRiskIndex.getHouseScore().compareTo(stuRiskIndex.getHouseScore()) != 0) {
                wrongCount += 1;
            }
            if (stuRiskIndex.getKnowledgeScore() == null || rightRiskIndex.getKnowledgeScore().compareTo(stuRiskIndex.getKnowledgeScore()) != 0) {
                wrongCount += 1;
            }
            if (stuRiskIndex.getRciScore() == null || rightRiskIndex.getRciScore().compareTo(stuRiskIndex.getRciScore()) != 0) {
                wrongCount += 1;
            }
            if (stuRiskIndex.getTolerateScore() == null || rightRiskIndex.getTolerateScore().compareTo(stuRiskIndex.getTolerateScore()) != 0) {
                wrongCount += 1;
            }
            if (stuRiskIndex.getMentalityScore() == null || rightRiskIndex.getMentalityScore().compareTo(stuRiskIndex.getMentalityScore()) != 0) {
                wrongCount += 1;
            }
            if (stuRiskIndex.getLossScore() == null || rightRiskIndex.getLossScore().compareTo(stuRiskIndex.getLossScore()) != 0) {
                wrongCount += 1;
            }

        }
        return wrongCount;
    }

    /**
     * 单个类型查询
     *
     * @param caseID
     * @param type
     * @return
     */
    @Override
    public ResultEntity<Object> getExamPoint(String caseID, String userId, String isAnswer, String type) {
        //判断是哪种考核点 增加相关表
        if (type.equals("风险测评-风险指标")) {
            CaseRiskIndexExample example = new CaseRiskIndexExample();
            example.createCriteria().andCaseidEqualTo(caseID).andIsAnswerEqualTo(isAnswer).andUseridEqualTo(userId);
            List<CaseRiskIndex> caseRiskIndices = caseRiskIndexMapper.selectByExample(example);
            if (caseRiskIndices == null || caseRiskIndices.isEmpty()) {
                return null;
            }
            return new ResultEntity<>(caseRiskIndices.get(0));
        }


        if (type.equals("财务分析-资产负债表")) {
            CaseFinanceLiabilityExample example = new CaseFinanceLiabilityExample();
            example.createCriteria().andCaseIdEqualTo(caseID).andIsAnswerEqualTo(isAnswer).andUserIdEqualTo(userId);
            List<CaseFinanceLiability> caseFinanceLiabilities = caseFinanceLiabilityMapper.selectByExample(example);
            if (caseFinanceLiabilities == null || caseFinanceLiabilities.isEmpty()) {
                return null;
            }
            return new ResultEntity<>(caseFinanceLiabilities.get(0));
        }

        if (type.equals("财务分析-收支储蓄表")) {
            CaseIncomeAndExpensesExample example = new CaseIncomeAndExpensesExample();
            example.createCriteria().andCaseidEqualTo(caseID).andIsAnswerEqualTo(isAnswer).andUserIdEqualTo(userId);
            List<CaseIncomeAndExpenses> caseIncomeAndExpenses = caseIncomeAndExpensesMapper.selectByExample(example);
            if (caseIncomeAndExpenses == null || caseIncomeAndExpenses.isEmpty()) {
                return null;
            }
            return new ResultEntity<>(caseIncomeAndExpenses.get(0));
        }

        if (type.equals("财务分析-现金流量表")) {
            CaseCashFlowExample example = new CaseCashFlowExample();
            example.createCriteria().andCaseidEqualTo(caseID).andIsAnswerEqualTo(isAnswer).andUserIdEqualTo(userId);
            List<CaseCashFlow> caseCashFlows = caseCashFlowMapper.selectByExample(example);
            if (caseCashFlows == null || caseCashFlows.isEmpty()) {
                return null;
            }
            return new ResultEntity<>(caseCashFlows.get(0));
        }

        if (type.equals("财务分析-财务比例分析")) {
            CaseFinancialRatiosExample example = new CaseFinancialRatiosExample();
            example.createCriteria().andCaseidEqualTo(caseID).andIsAnswerEqualTo(isAnswer).andUserIdEqualTo(userId);
            List<CaseFinancialRatiosWithBLOBs> caseFinancialRatiosWithBLOBs = caseFinancialRatiosMapper.selectByExampleWithBLOBs(example);
            if (caseFinancialRatiosWithBLOBs == null || caseFinancialRatiosWithBLOBs.isEmpty()) {
                return null;
            }
            return new ResultEntity<>(caseFinancialRatiosWithBLOBs.get(0));
        }

        if (type.equals("现金规划")) {
            CaseCashPlanExample example = new CaseCashPlanExample();
            example.createCriteria().andCaseidEqualTo(caseID).andIsAnswerEqualTo(isAnswer).andUserIdEqualTo(userId);
            List<CaseCashPlan> caseCashPlans = caseCashPlanMapper.selectByExampleWithBLOBs(example);
            if (caseCashPlans == null || caseCashPlans.isEmpty()) {
                return null;
            }
            return new ResultEntity<>(caseCashPlans.get(0));
        }

        if (type.equals("生涯规划-教育规划")) {
            CaseLifeEducationPlanExample example = new CaseLifeEducationPlanExample();
            example.createCriteria().andCaseidEqualTo(caseID).andIsAnswerEqualTo(isAnswer).andUserIdEqualTo(userId);
            List<CaseLifeEducationPlan> caseLifeEducationPlans = caseLifeEducationPlanMapper.selectByExampleWithBLOBs(example);
            if (caseLifeEducationPlans == null || caseLifeEducationPlans.isEmpty()) {
                return null;
            }
            return new ResultEntity<>(caseLifeEducationPlans.get(0));
        }

        if (type.equals("生涯规划-消费规划")) {
            //todo 暂无数据库表
            return null;
        }


        if (type.equals("生涯规划-创业规划")) {
            CaseStartAnUndertakingPlanExample example = new CaseStartAnUndertakingPlanExample();
            example.createCriteria().andCaseidEqualTo(caseID).andIsAnswerEqualTo(isAnswer).andUserIdEqualTo(userId);
            List<CaseStartAnUndertakingPlan> caseStartAnUndertakingPlans = caseStartAnUndertakingPlanMapper.selectByExampleWithBLOBs(example);
            if (caseStartAnUndertakingPlans == null || caseStartAnUndertakingPlans.isEmpty()) {
                return null;
            }
            return new ResultEntity<>(caseStartAnUndertakingPlans.get(0));
        }

        if (type.equals("生涯规划-退休规划")) {
            CaseRetirementPlanExample example = new CaseRetirementPlanExample();
            example.createCriteria().andCaseidEqualTo(caseID).andIsAnswerEqualTo(isAnswer).andUserIdEqualTo(userId);
            List<CaseRetirementPlan> caseRetirementPlans = caseRetirementPlanMapper.selectByExampleWithBLOBs(example);
            if (caseRetirementPlans == null || caseRetirementPlans.isEmpty()) {
                return null;
            }
            return new ResultEntity<>(caseRetirementPlans.get(0));
        }

        if (type.equals("生涯规划-保险规划")) {
            CaseInsurancePlanExample example = new CaseInsurancePlanExample();
            example.createCriteria().andCaseidEqualTo(caseID).andIsAnswerEqualTo(isAnswer).andUserIdEqualTo(userId);
            List<CaseInsurancePlan> caseInsurancePlans = caseInsurancePlanMapper.selectByExampleWithBLOBs(example);
            if (caseInsurancePlans == null || caseInsurancePlans.isEmpty()) {
                return null;
            }
            return new ResultEntity<>(caseInsurancePlans.get(0));
        }

        if (type.equals("投资规划")) {
            // todo 表暂时没有
            return null;
        }

        if (type.equals("税务筹划")) {
            CaseTaxPlanExample example = new CaseTaxPlanExample();
            example.createCriteria().andCaseidEqualTo(caseID).andIsAnswerEqualTo(isAnswer).andUserIdEqualTo(userId);
            List<CaseTaxPlan> caseTaxPlans = caseTaxPlanMapper.selectByExampleWithBLOBs(example);
            if (caseTaxPlans == null || caseTaxPlans.isEmpty()) {
                return null;
            }
            return new ResultEntity<>(caseTaxPlans.get(0));
        }

        if (type.equals("财产分配")) {
            CaseDistributionOfPropertyExample example = new CaseDistributionOfPropertyExample();
            example.createCriteria().andCaseidEqualTo(caseID).andIsAnswerEqualTo(isAnswer).andUserIdEqualTo(userId);
            List<CaseDistributionOfPropertyWithBLOBs> caseDistributionOfPropertyWithBLOBs = caseDistributionOfPropertyMapper.selectByExampleWithBLOBs(example);
            if (caseDistributionOfPropertyWithBLOBs == null || caseDistributionOfPropertyWithBLOBs.isEmpty()) {
                return null;
            }
            return new ResultEntity<>(caseDistributionOfPropertyWithBLOBs.get(0));
        }

        if (type.equals("财产传承")) {
            CaseHeritageExample example = new CaseHeritageExample();
            example.createCriteria().andCaseidEqualTo(caseID).andIsAnswerEqualTo(isAnswer).andUserIdEqualTo(userId);
            List<CaseHeritageWithBLOBs> caseHeritageWithBLOBs = caseHeritageMapper.selectByExampleWithBLOBs(example);
            if (caseHeritageWithBLOBs == null || caseHeritageWithBLOBs.isEmpty()) {
                return null;
            }
            return new ResultEntity<>(caseHeritageWithBLOBs.get(0));
        }
        return null;
    }


    /**
     * 编辑
     *
     * @param json
     * @param type
     * @return
     */
    @Override
    public ResultEntity<HttpStatus> updateExamPoint(String json, String type) {
        //判断是哪种考核点 增加相关表
        try {
            Gson gson = new Gson();
            if (StringUtils.isNotBlank(json)) {
                if (type.equals("风险测评-风险指标")) {
                    CaseRiskIndex caseRiskIndex = gson.fromJson(json, CaseRiskIndex.class);
                    caseRiskIndexMapper.updateByPrimaryKeySelective(caseRiskIndex);
                    return new ResultEntity<HttpStatus>(HttpStatus.OK, "编辑成功！");
                }

                if (type.equals("财务分析-资产负债表")) {
                    CaseFinanceLiability caseFinanceLiability = gson.fromJson(json, CaseFinanceLiability.class);
                    caseFinanceLiabilityMapper.updateByPrimaryKeySelective(caseFinanceLiability);
                    return new ResultEntity<HttpStatus>(HttpStatus.OK, "编辑成功！");
                }

                if (type.equals("财务分析-收支储蓄表")) {
                    CaseIncomeAndExpenses caseIncomeAndExpenses = gson.fromJson(json, CaseIncomeAndExpenses.class);
                    caseIncomeAndExpensesMapper.updateByPrimaryKeySelective(caseIncomeAndExpenses);
                    return new ResultEntity<HttpStatus>(HttpStatus.OK, "编辑成功！");
                }

                if (type.equals("财务分析-现金流量表")) {
                    CaseCashFlow caseCashFlow = gson.fromJson(json, CaseCashFlow.class);
                    caseCashFlowMapper.updateByPrimaryKeySelective(caseCashFlow);
                    return new ResultEntity<HttpStatus>(HttpStatus.OK, "编辑成功！");
                }

                if (type.equals("财务分析-财务比例分析")) {
                    CaseFinancialRatiosWithBLOBs caseFinancialRatios = gson.fromJson(json, CaseFinancialRatiosWithBLOBs.class);
                    caseFinancialRatiosMapper.updateByPrimaryKeySelective(caseFinancialRatios);
                    return new ResultEntity<HttpStatus>(HttpStatus.OK, "编辑成功！");
                }

                if (type.equals("现金规划")) {
                    CaseCashPlan caseCashPlan = gson.fromJson(json, CaseCashPlan.class);
                    caseCashPlanMapper.updateByPrimaryKeySelective(caseCashPlan);
                    return new ResultEntity<HttpStatus>(HttpStatus.OK, "编辑成功！");
                }

                if (type.equals("生涯规划-教育规划")) {
                    CaseLifeEducationPlan caseLifeEducationPlan = gson.fromJson(json, CaseLifeEducationPlan.class);
                    caseLifeEducationPlanMapper.updateByPrimaryKeySelective(caseLifeEducationPlan);
                    return new ResultEntity<HttpStatus>(HttpStatus.OK, "编辑成功！");
                }

                if (type.equals("生涯规划-消费规划")) {
                    //todo 暂无数据库表
                    return new ResultEntity<HttpStatus>(HttpStatus.OK, "编辑成功！");
                }


                if (type.equals("生涯规划-创业规划")) {
                    CaseStartAnUndertakingPlan caseStartAnUndertakingPlan = gson.fromJson(json, CaseStartAnUndertakingPlan.class);
                    caseStartAnUndertakingPlanMapper.updateByPrimaryKeySelective(caseStartAnUndertakingPlan);
                    return new ResultEntity<HttpStatus>(HttpStatus.OK, "编辑成功！");
                }

                if (type.equals("生涯规划-退休规划")) {
                    CaseRetirementPlan caseRetirementPlan = gson.fromJson(json, CaseRetirementPlan.class);
                    caseRetirementPlanMapper.updateByPrimaryKeySelective(caseRetirementPlan);
                    return new ResultEntity<HttpStatus>(HttpStatus.OK, "编辑成功！");
                }

                if (type.equals("生涯规划-保险规划")) {
                    CaseInsurancePlan caseInsurancePlan = gson.fromJson(json, CaseInsurancePlan.class);
                    caseInsurancePlanMapper.updateByPrimaryKeySelective(caseInsurancePlan);
                    return new ResultEntity<HttpStatus>(HttpStatus.OK, "编辑成功！");
                }

                if (type.equals("投资规划")) {
                    // todo 表暂时没有
                    return null;
                }

                if (type.equals("税务筹划")) {
                    CaseTaxPlan caseTaxPlan = gson.fromJson(json, CaseTaxPlan.class);
                    caseTaxPlanMapper.updateByPrimaryKeySelective(caseTaxPlan);
                    return new ResultEntity<HttpStatus>(HttpStatus.OK, "编辑成功！");
                }

                if (type.equals("财产分配")) {
                    CaseDistributionOfPropertyWithBLOBs caseDistributionOfPropertyWithBLOBs = gson.fromJson(json, CaseDistributionOfPropertyWithBLOBs.class);
                    caseDistributionOfPropertyMapper.updateByPrimaryKeySelective(caseDistributionOfPropertyWithBLOBs);
                    return new ResultEntity<HttpStatus>(HttpStatus.OK, "编辑成功！");
                }

                if (type.equals("财产传承")) {
                    CaseHeritageWithBLOBs caseHeritageWithBLOBs = gson.fromJson(json, CaseHeritageWithBLOBs.class);
                    caseHeritageMapper.updateByPrimaryKeySelective(caseHeritageWithBLOBs);
                    return new ResultEntity<HttpStatus>(HttpStatus.OK, "编辑成功！");
                }
            }
        } catch (Exception e) {
            return new ResultEntity<HttpStatus>(HttpStatus.INTERNAL_SERVER_ERROR, "服务器异常，请联系管理员！");
        }
        return null;
    }
}